
function [y] = rapidGrowth(x,Fs,T,attackTime,releaseTime)
N = length(x);
y = zeros(N,1);
lin_A = zeros(N,1);

% Initialize separate attack and release times
alphaA = exp(-log(9)/(Fs * attackTime));
alphaR = exp(-log(9)/(Fs * releaseTime));

gainSmoothPrev = 0; % Initialize smoothing variable

% Loop over each sample to see if it is above thresh
for n = 1:N
    % Turn the input signal into a uni-polar signal on the dB scale
    x_uni = abs(x(n,1));
    x_dB = 20*log10(x_uni/1);
    % Ensure there are no values of negative infinity
    if  x_dB < -144
        x_dB = -144;
    end
    
    % Static Characteristics
    if  x_dB<T
        R = 1;
        gainSC = T + (x_dB - T)/R;% Do not perform expansion 
    elseif x_dB >T && x_dB<-20
        R = 0.6;
        gainSC = T + (x_dB - T)/R; % Perform Upwards compression
    elseif  x_dB>=-30
        R = 1;
        gainSC = T + (x_dB - T)/R;% Do not perform expansion 
    else
            gainSC = x_dB;
    end
          
    gainChange_dB = gainSC - x_dB;
    % smooth over the gainChange
    if gainChange_dB < gainSmoothPrev
        % attack mode
        gainSmooth = ((1-alphaA)*gainChange_dB) ...
            +(alphaA*gainSmoothPrev);
    else
        % release
        gainSmooth = ((1-alphaR)*gainChange_dB) ...
            +(alphaR*gainSmoothPrev);
    end

    lin_A(n,1) = 10^(gainSmooth/20);
    
    % Apply amplitude to input sample
    y(n,1) = lin_A(n,1) * x(n,1);
    
    % Update gainSmoothPrev used in the next sample of the loop
    gainSmoothPrev = gainSmooth;
end

% This function is based on the open source code found in 
% "Hack Audio: An Introduction to Computer Programming and Digital Signal
% Processing in MATLAB" © 2019 Taylor & Francis.
% link: https://github.com/HackAudio/textbookcode/blob/master/Ch_18/compressor.m